pub enum ExtensionInitializationParams {
Show 16 variants
ConfidentialTransferMint {
authority: Option<Address>,
auto_approve_new_accounts: bool,
auditor_elgamal_pubkey: Option<PodElGamalPubkey>,
},
DefaultAccountState {
state: AccountState,
},
MintCloseAuthority {
close_authority: Option<Address>,
},
TransferFeeConfig {
transfer_fee_config_authority: Option<Address>,
withdraw_withheld_authority: Option<Address>,
transfer_fee_basis_points: u16,
maximum_fee: u64,
},
InterestBearingConfig {
rate_authority: Option<Address>,
rate: i16,
},
NonTransferable,
PermanentDelegate {
delegate: Address,
},
TransferHook {
authority: Option<Address>,
program_id: Option<Address>,
},
MetadataPointer {
authority: Option<Address>,
metadata_address: Option<Address>,
},
ConfidentialTransferFeeConfig {
authority: Option<Address>,
withdraw_withheld_authority_elgamal_pubkey: PodElGamalPubkey,
},
GroupPointer {
authority: Option<Address>,
group_address: Option<Address>,
},
GroupMemberPointer {
authority: Option<Address>,
member_address: Option<Address>,
},
ScaledUiAmountConfig {
authority: Option<Address>,
multiplier: f64,
},
PausableConfig {
authority: Address,
},
PermissionedBurnConfig {
authority: Address,
},
ConfidentialMintBurn {
supply_elgamal_pubkey: PodElGamalPubkey,
decryptable_supply: PodAeCiphertext,
},
}Expand description
Encapsulates initializing an extension
Variants
ConfidentialTransferMint
DefaultAccountState
Fields

state: AccountStateMintCloseAuthority
Fields
TransferFeeConfig
InterestBearingConfig
NonTransferable
PermanentDelegate
TransferHook
MetadataPointer
ConfidentialTransferFeeConfig
Fields
GroupPointer
GroupMemberPointer
ScaledUiAmountConfig
PausableConfig
Fields
PermissionedBurnConfig
Fields
ConfidentialMintBurn
Implementations
Sourceimpl ExtensionInitializationParams
impl ExtensionInitializationParams
Sourcepub fn extension(&self) -> ExtensionType
pub fn extension(&self) -> ExtensionType
Get the extension type associated with the init params
Sourcepub fn instruction(
self,
token_program_id: &Address,
mint: &Address,
) -> Result<Instruction, ProgramError>
pub fn instruction( self, token_program_id: &Address, mint: &Address, ) -> Result<Instruction, ProgramError>
Generate an appropriate initialization instruction for the given mint